==> lori_sdk-0.6.0%2B1.tar.gz: lib/data/api/sales/sales_catalog_api.dart <==
import 'dart:async';

import 'package:dio/dio.dart';
import 'package:flutter/material.dart';
import 'package:lori_sdk/data/database/interfaces/cartDao.dart';
import 'package:lori_sdk/data/lori_api.dart';
import 'package:lori_sdk/data/models/filter/filters_response.dart';
import 'package:lori_sdk/data/models/product/product.dart';
import 'package:lori_sdk/data/models/product/productOrder.dart';
import 'package:lori_sdk/data/models/response/productPaginationResult.dart';
import 'package:lori_sdk/data/models/v2/category.dart';
import 'package:lori_sdk/data/models/cart/seller.dart';

class SalesCatalogApi {
  // We have two catalog APIs:
  //  - The REGULAR catalog API, whose route is "catalog/"
  //  - The PER SELLER catalog API, whose route is "catalog/sellers/{sellerId}/"
  // The placeholder #catalog_api# should be replaced by the correct value.
  // Please use the method `_catalogEndpoint` to generate the correct routes.
  static const API_CATEGORIES = 'sales/#catalog_api#/categories';
  static const API_CATEGORIES_CHILDREN = 'sales/#catalog_api#/categories/%/children';

  static const API_PRODUCT_BY_ID = 'sales/#catalog_api#/products/%';
  static const API_PRODUCTS_BY_CATEGORY = 'sales/#catalog_api#/categories/%/products';
  static const API_PRODUCTS_BY_SEARCH_TERM = 'sales/#catalog_api#/products/search/%';
  static const API_PRODUCTS_BY_TAG = 'sales/#catalog_api#/tags/%/products';

  static const API_PRODUCTS_FILTERS = 'sales/catalog/v2/filters/';
  static const API_PRODUCTS_BY_FILTERS = 'sales/catalog/v2/search/products/';

  Dio _requester;

  SalesCatalogApi({@required Dio requester}) : this._requester = requester;

  /// region Category API endpoints

  Future<ApiCallback<List<Category>>> getCategories({bool perSeller = false}) async {
    try {
      var response = await _requester.get(
        await _catalogEndpoint(
          API_CATEGORIES,
          includeSeller: perSeller
        ),
        options: Options(responseType: ResponseType.json)
      );
      var responseData = response.data as List;
      var categories = responseData.map((e) => Category.fromJson(e)).toList();

      return ApiCallback<List<Category>>(
          isSuccessful: true, resultData: categories);
    } on DioError catch (e) {
      return ApiCallback<List<Category>>().defaultErrorCallback(e);
    }
  }

  Future<ApiCallback<List<Category>>> getChildrenCategories({@required String parentCategoryId, bool perSeller = false}) async {
    try {
      var response = await _requester.get(
        await _catalogEndpoint(
          API_CATEGORIES_CHILDREN.replaceAll('%', parentCategoryId),
          includeSeller: perSeller
        ),
        options: Options(responseType: ResponseType.json)
      );
      var responseData = response.data as List;
      var categories = List<Category>();
      for (var row in responseData) {
        categories.add(Category.fromJson(row));
      }
      return ApiCallback<List<Category>>(
          isSuccessful: true, resultData: categories);
    } on DioError catch (e) {
      return ApiCallback<List<Category>>().defaultErrorCallback(e);
    }
  }

  /// endregion

  /// region Product API endpoints

  Future<ApiCallback<Product>> getProduct(String productId, {Seller seller, bool perSeller = false}) async {
    try {
      var response = await _requester.get(
        await _catalogEndpoint(
          API_PRODUCT_BY_ID.replaceAll('%', productId),
          includeSeller: perSeller
        ),
      );
      return ApiCallback<Product>(
          isSuccessful: true, resultData: Product.fromJson(response.data));
    } on DioError catch (e) {
      return ApiCallback<Product>().defaultErrorCallback(e);
    }
  }

  Future<ApiCallback<ProductPaginationResult>> getProductsByCategory({@required String categoryId, int page = 1, int perPage = 20, String continuationToken, ProductOrder sort, bool perSeller = false}) async {
    Map<String, dynamic> queryParameters = {
      'page': page,
      'perPage': perPage
    };

    queryParameters.addAll(_queryParametersForPagedProductRequest(continuationToken: continuationToken, sort: sort));

    try {
      Stopwatch stopwatch = new Stopwatch()..start();
      var response = await _requester.get(
          await _catalogEndpoint(
            API_PRODUCTS_BY_CATEGORY.replaceAll("%", categoryId),
            includeSeller: perSeller
          ),
          queryParameters: queryParameters,
          options: Options(responseType: ResponseType.json));
      var paginationResult = ProductPaginationResult.fromJson(response.data);
      print("Page ${paginationResult.page}/${paginationResult.maxPage} loaded in ${stopwatch.elapsedMilliseconds}ms");
      return ApiCallback<ProductPaginationResult>(
          isSuccessful: true,
          resultData: paginationResult);
    } on DioError catch (e) {
      return ApiCallback<ProductPaginationResult>().defaultErrorCallback(e);
    }
  }

  Future<ApiCallback<ProductPaginationResult>> getProductsBySearch({String term, int page = 1, int perPage = 20, String continuationToken, ProductOrder sort, bool perSeller = false}) async {
    Map<String, dynamic> queryParameters = {
      'page': page,
      'perPage': perPage
    };

    queryParameters.addAll(_queryParametersForPagedProductRequest(continuationToken: continuationToken, sort: sort));

    try {
      Stopwatch stopwatch = new Stopwatch()..start();
      var response = await _requester.get(
          await _catalogEndpoint(
            API_PRODUCTS_BY_SEARCH_TERM.replaceAll("%", term),
            includeSeller: perSeller
          ),
          queryParameters: queryParameters,
          options: Options(responseType: ResponseType.json));
      var paginationResult = ProductPaginationResult.fromJson(response.data);
      print("Page ${paginationResult.page}/${paginationResult.maxPage} loaded in ${stopwatch.elapsedMilliseconds}ms");
      return ApiCallback<ProductPaginationResult>(
          isSuccessful: true,
          resultData: paginationResult);
    } on DioError catch (e) {
      return ApiCallback<ProductPaginationResult>().defaultErrorCallback(e);
    }
  }

  Future<ApiCallback<ProductPaginationResult>> getProductsByTag({String tag, int page = 1, int perPage = 20, String continuationToken, ProductOrder sort, bool perSeller = false}) async {
    Map<String, dynamic> queryParameters = {
      'page': page,
      'perPage': perPage
    };

    queryParameters.addAll(_queryParametersForPagedProductRequest(continuationToken: continuationToken, sort: sort));

    try {
      Stopwatch stopwatch = new Stopwatch()..start();
      var escapedTag = Uri.encodeComponent(tag);
      var response = await _requester.get(
        await _catalogEndpoint(
          API_PRODUCTS_BY_TAG.replaceAll("%", escapedTag),
          includeSeller: perSeller
        ),
        queryParameters: queryParameters,
        options: Options(responseType: ResponseType.json)
      );
      var paginationResult = ProductPaginationResult.fromJson(response.data);
      print("Page ${paginationResult.page}/${paginationResult.maxPage} loaded in ${stopwatch.elapsedMilliseconds}ms");
      return ApiCallback<ProductPaginationResult>(
          isSuccessful: true,
          resultData: paginationResult);
    } on DioError catch (e) {
      return ApiCallback<ProductPaginationResult>().defaultErrorCallback(e);
    }
  }

  Future<ApiCallback<FiltersResponse>> getFilters({
      String categoryId,
      bool perSeller = false,
      String term,
      String tag,
    }) async {
    try {
      Map<String, dynamic> queryParameters = {};

      if(perSeller){
        var cart = await CartDao().get();
        if(cart.seller != null){
          queryParameters["sellerId"] = cart.seller.id;
        }
      }

      if(categoryId != null) {
        queryParameters["categoryId"] = categoryId;
      }

      if(term != null && term.isNotEmpty){
        queryParameters["query"] = term;
      }

      if(tag != null && tag.isNotEmpty){
        queryParameters["tag"] = tag;
      }

      var response = await _requester.get(
        API_PRODUCTS_FILTERS,
        options: Options(responseType: ResponseType.json),
        queryParameters: queryParameters,
      );
      FiltersResponse filtersModel = FiltersResponse.fromJson(response.data);
      return ApiCallback<FiltersResponse>(isSuccessful: true, resultData: filtersModel);
    } on DioError catch (e) {
      return ApiCallback<FiltersResponse>().defaultErrorCallback(e);
    } catch (e){
      return ApiCallback(isSuccessful: false, error: null, resultErrorMessage: e.toString());
    }
  }

  Future<ApiCallback<ProductPaginationResult>> getProductsByFilters({
    int page = 1,
    int perPage = 20,
    String continuationToken,
    ProductOrder sort,
    bool perSeller = false,
    Map<String, dynamic> filterParams,
  }) async {
    Map<String, dynamic> queryParameters = {'page': page, 'perPage': perPage};

    queryParameters.addAll(_queryParametersForPagedProductRequest(continuationToken: continuationToken, sort: sort));
    queryParameters.addAll(filterParams);

    try {
      Stopwatch stopwatch = new Stopwatch()..start();
      var response = await _requester.get(
          API_PRODUCTS_BY_FILTERS,
          queryParameters: queryParameters,
          options: Options(responseType: ResponseType.json));
      var paginationResult = ProductPaginationResult.fromJson(response.data);
      print("Page ${paginationResult.page}/${paginationResult.maxPage} loaded in ${stopwatch.elapsedMilliseconds}ms");
      print(response.request.uri.toString());
      return ApiCallback<ProductPaginationResult>(
          isSuccessful: true,
          resultData: paginationResult);
    } on DioError catch (e) {
      print(e.request.uri.toString());
      return ApiCallback<ProductPaginationResult>().defaultErrorCallback(e);
    }
  }

  /// endregion

  /// region Helpers

  Future<String> _catalogEndpoint(String endpoint, {bool includeSeller = false}) async {
    if (includeSeller) {
      var cart = await CartDao().get();
      if (cart.seller != null) {
        return endpoint.replaceAll(
            '#catalog_api#',
            "catalog/v2/sellers/${cart.seller.id}"
        );
      }
    }

    return endpoint.replaceAll('#catalog_api#', 'catalog/v2');
  }

  Map<String, dynamic> _queryParametersForPagedProductRequest({String continuationToken, ProductOrder sort}) {
    Map<String, dynamic> queryParameters = {};

    if (continuationToken != null) {
      queryParameters['continuationToken'] = continuationToken;
    }

    var sortParams = _queryParametersForProductSort(sort);
    queryParameters.addAll(sortParams);

    return queryParameters;
  }

  Map<String, dynamic> _queryParametersForProductSort(ProductOrder sort) {
    Map<String, dynamic> queryParameters = {};

    const SORT_FIELD_KEY = 'sortField';
    const SORT_ASCENDING_KEY = 'sortAscending';

    if (sort != null && sort.parameterName != null) {
      switch (sort) {
        case ProductOrder.none:
          break;
        case ProductOrder.lowestPrice:
          queryParameters[SORT_FIELD_KEY] = 'price';
          queryParameters[SORT_ASCENDING_KEY] = true;
          break;
        case ProductOrder.higherPrice:
          queryParameters[SORT_FIELD_KEY] = 'price';
          queryParameters[SORT_ASCENDING_KEY] = false;
          break;
        case ProductOrder.mostFavored:
          queryParameters[SORT_FIELD_KEY] = 'favoriteCount';
          queryParameters[SORT_ASCENDING_KEY] = false;
          break;
        case ProductOrder.bestSellers:
          queryParameters[SORT_FIELD_KEY] = 'salesCount';
          queryParameters[SORT_ASCENDING_KEY] = false;
          break;
        case ProductOrder.releaseDate:
          queryParameters[SORT_FIELD_KEY] = 'releaseDate';
          queryParameters[SORT_ASCENDING_KEY] = false;
          break;
        case ProductOrder.aToZ:
          queryParameters[SORT_FIELD_KEY] = 'name';
          queryParameters[SORT_ASCENDING_KEY] = true;
          break;
        case ProductOrder.zToA:
          queryParameters[SORT_FIELD_KEY] = 'name';
          queryParameters[SORT_ASCENDING_KEY] = false;
          break;
      }
    }

    return queryParameters;
  }

  /// endregion

}

==> lori_sdk-0.6.3%2B1.tar.gz: lib/data/api/sales/sales_catalog_api.dart <==
import 'dart:async';

import 'package:dio/dio.dart';
import 'package:flutter/material.dart';
import 'package:lori_sdk/data/database/interfaces/cartDao.dart';
import 'package:lori_sdk/data/lori_api.dart';
import 'package:lori_sdk/data/models/configurations/internalConfigurations.dart';
import 'package:lori_sdk/data/models/filter/filters_response.dart';
import 'package:lori_sdk/data/models/product/product.dart';
import 'package:lori_sdk/data/models/product/productOrder.dart';
import 'package:lori_sdk/data/models/response/productPaginationResult.dart';
import 'package:lori_sdk/data/models/v2/category.dart';
import 'package:lori_sdk/data/models/cart/seller.dart';

class SalesCatalogApi {
  // We have two catalog APIs:
  //  - The REGULAR catalog API, whose route is "catalog/"
  //  - The PER SELLER catalog API, whose route is "catalog/sellers/{sellerId}/"
  // The placeholder #catalog_api# should be replaced by the correct value.
  // Please use the method `_catalogEndpoint` to generate the correct routes.

  static const API_CATEGORIES = 'sales/#catalog_api#/categories';
  static const API_CATEGORIES_CHILDREN = 'sales/#catalog_api#/categories/%/children';

  static const API_PRODUCT_BY_ID = 'sales/#catalog_api#/products/%';
  static const API_PRODUCTS_BY_CATEGORY = 'sales/#catalog_api#/categories/%/products';
  static const API_PRODUCTS_BY_SEARCH_TERM = 'sales/#catalog_api#/products/search/%';
  static const API_PRODUCTS_BY_TAG = 'sales/#catalog_api#/tags/%/products';

  static const API_PRODUCTS_FILTERS = 'sales/#catalog_api#/filters/';
  static const API_PRODUCTS_BY_FILTERS = 'sales/#catalog_api#/search/products/';


  Dio _requester;

  SalesCatalogApi({@required Dio requester}) : this._requester = requester;

  /// region Category API endpoints

  Future<ApiCallback<List<Category>>> getCategories({bool perSeller = false}) async {
    try {
      var response = await _requester.get(
        await _catalogEndpoint(
          API_CATEGORIES,
          includeSeller: perSeller
        ),
        options: Options(responseType: ResponseType.json)
      );
      var responseData = response.data as List;
      var categories = responseData.map((e) => Category.fromJson(e)).toList();

      return ApiCallback<List<Category>>(
          isSuccessful: true, resultData: categories);
    } on DioError catch (e) {
      return ApiCallback<List<Category>>().defaultErrorCallback(e);
    }
  }

  Future<ApiCallback<List<Category>>> getChildrenCategories({@required String parentCategoryId, bool perSeller = false}) async {
    try {
      var response = await _requester.get(
        await _catalogEndpoint(
          API_CATEGORIES_CHILDREN.replaceAll('%', parentCategoryId),
          includeSeller: perSeller
        ),
        options: Options(responseType: ResponseType.json)
      );
      var responseData = response.data as List;
      var categories = List<Category>();
      for (var row in responseData) {
        categories.add(Category.fromJson(row));
      }
      return ApiCallback<List<Category>>(
          isSuccessful: true, resultData: categories);
    } on DioError catch (e) {
      return ApiCallback<List<Category>>().defaultErrorCallback(e);
    }
  }

  /// endregion

  /// region Product API endpoints

  Future<ApiCallback<Product>> getProduct(String productId, {Seller seller, bool perSeller = false}) async {
    try {
      var response = await _requester.get(
        await _catalogEndpoint(
          API_PRODUCT_BY_ID.replaceAll('%', productId),
          includeSeller: perSeller
        ),
      );
      return ApiCallback<Product>(
          isSuccessful: true, resultData: Product.fromJson(response.data));
    } on DioError catch (e) {
      return ApiCallback<Product>().defaultErrorCallback(e);
    }
  }

  Future<ApiCallback<ProductPaginationResult>> getProductsByCategory({@required String categoryId, int page = 1, int perPage = 20, String continuationToken, ProductOrder sort, bool perSeller = false}) async {
    Map<String, dynamic> queryParameters = {
      'page': page,
      'perPage': perPage
    };

    queryParameters.addAll(_queryParametersForPagedProductRequest(continuationToken: continuationToken, sort: sort));

    try {
      Stopwatch stopwatch = new Stopwatch()..start();
      var response = await _requester.get(
          await _catalogEndpoint(
            API_PRODUCTS_BY_CATEGORY.replaceAll("%", categoryId),
            includeSeller: perSeller
          ),
          queryParameters: queryParameters,
          options: Options(responseType: ResponseType.json));
      var paginationResult = ProductPaginationResult.fromJson(response.data);
      print("Page ${paginationResult.page}/${paginationResult.maxPage} loaded in ${stopwatch.elapsedMilliseconds}ms");
      return ApiCallback<ProductPaginationResult>(
          isSuccessful: true,
          resultData: paginationResult);
    } on DioError catch (e) {
      return ApiCallback<ProductPaginationResult>().defaultErrorCallback(e);
    }
  }

  Future<ApiCallback<ProductPaginationResult>> getProductsBySearch({String term, int page = 1, int perPage = 20, String continuationToken, ProductOrder sort, bool perSeller = false}) async {
    Map<String, dynamic> queryParameters = {
      'page': page,
      'perPage': perPage
    };

    queryParameters.addAll(_queryParametersForPagedProductRequest(continuationToken: continuationToken, sort: sort));

    try {
      Stopwatch stopwatch = new Stopwatch()..start();
      var response = await _requester.get(
          await _catalogEndpoint(
            API_PRODUCTS_BY_SEARCH_TERM.replaceAll("%", term),
            includeSeller: perSeller
          ),
          queryParameters: queryParameters,
          options: Options(responseType: ResponseType.json));
      var paginationResult = ProductPaginationResult.fromJson(response.data);
      print("Page ${paginationResult.page}/${paginationResult.maxPage} loaded in ${stopwatch.elapsedMilliseconds}ms");
      return ApiCallback<ProductPaginationResult>(
          isSuccessful: true,
          resultData: paginationResult);
    } on DioError catch (e) {
      return ApiCallback<ProductPaginationResult>().defaultErrorCallback(e);
    }
  }

  Future<ApiCallback<ProductPaginationResult>> getProductsByTag({String tag, int page = 1, int perPage = 20, String continuationToken, ProductOrder sort, bool perSeller = false}) async {
    Map<String, dynamic> queryParameters = {
      'page': page,
      'perPage': perPage
    };

    queryParameters.addAll(_queryParametersForPagedProductRequest(continuationToken: continuationToken, sort: sort));

    try {
      Stopwatch stopwatch = new Stopwatch()..start();
      var escapedTag = Uri.encodeComponent(tag);
      var response = await _requester.get(
        await _catalogEndpoint(
          API_PRODUCTS_BY_TAG.replaceAll("%", escapedTag),
          includeSeller: perSeller
        ),
        queryParameters: queryParameters,
        options: Options(responseType: ResponseType.json)
      );
      var paginationResult = ProductPaginationResult.fromJson(response.data);
      print("Page ${paginationResult.page}/${paginationResult.maxPage} loaded in ${stopwatch.elapsedMilliseconds}ms");
      return ApiCallback<ProductPaginationResult>(
          isSuccessful: true,
          resultData: paginationResult);
    } on DioError catch (e) {
      return ApiCallback<ProductPaginationResult>().defaultErrorCallback(e);
    }
  }

  Future<ApiCallback<FiltersResponse>> getFilters({
      String categoryId,
      bool perSeller = false,
      String term,
      String tag,
    }) async {
    try {
      Map<String, dynamic> queryParameters = {};

      if(perSeller){
        var cart = await CartDao().get();
        if(cart.seller != null){
          queryParameters["sellerId"] = cart.seller.id;
        }
      }

      if(categoryId != null) {
        queryParameters["categoryId"] = categoryId;
      }

      if(term != null && term.isNotEmpty){
        queryParameters["query"] = term;
      }

      if(tag != null && tag.isNotEmpty){
        queryParameters["tag"] = tag;
      }

      var response = await _requester.get(
        await _catalogEndpoint(
            API_PRODUCTS_FILTERS,
            includeSeller: false
        ),
        options: Options(responseType: ResponseType.json),
        queryParameters: queryParameters,
      );
      FiltersResponse filtersModel = FiltersResponse.fromJson(response.data);
      return ApiCallback<FiltersResponse>(isSuccessful: true, resultData: filtersModel);
    } on DioError catch (e) {
      return ApiCallback<FiltersResponse>().defaultErrorCallback(e);
    } catch (e){
      return ApiCallback(isSuccessful: false, error: null, resultErrorMessage: e.toString());
    }
  }

  Future<ApiCallback<ProductPaginationResult>> getProductsByFilters({
    int page = 1,
    int perPage = 20,
    String continuationToken,
    ProductOrder sort,
    bool perSeller = false,
    Map<String, dynamic> filterParams,
  }) async {
    Map<String, dynamic> queryParameters = {'page': page, 'perPage': perPage};

    queryParameters.addAll(_queryParametersForPagedProductRequest(continuationToken: continuationToken, sort: sort));
    queryParameters.addAll(filterParams);

    try {
      Stopwatch stopwatch = new Stopwatch()..start();
      var response = await _requester.get(
          await _catalogEndpoint(
              API_PRODUCTS_BY_FILTERS,
              includeSeller: false
          ),
          queryParameters: queryParameters,
          options: Options(responseType: ResponseType.json));
      var paginationResult = ProductPaginationResult.fromJson(response.data);
      print("Page ${paginationResult.page}/${paginationResult.maxPage} loaded in ${stopwatch.elapsedMilliseconds}ms");
      print(response.request.uri.toString());
      return ApiCallback<ProductPaginationResult>(
          isSuccessful: true,
          resultData: paginationResult);
    } on DioError catch (e) {
      print(e.request.uri.toString());
      return ApiCallback<ProductPaginationResult>().defaultErrorCallback(e);
    }
  }

  /// endregion

  /// region Helpers

  Future<String> _catalogEndpoint(String endpoint, {bool includeSeller = false}) async {
    String setV2 = LoriApi.useFilter ? "catalog/v2" : "catalog";
    if (includeSeller) {
      var cart = await CartDao().get();
      if (cart.seller != null) {
        return endpoint.replaceAll(
            '#catalog_api#',
            "$setV2/sellers/${cart.seller.id}"
        );
      }
    }

    return endpoint.replaceAll('#catalog_api#', '$setV2');
  }

  Map<String, dynamic> _queryParametersForPagedProductRequest({String continuationToken, ProductOrder sort}) {
    Map<String, dynamic> queryParameters = {};

    if (continuationToken != null) {
      queryParameters['continuationToken'] = continuationToken;
    }

    var sortParams = _queryParametersForProductSort(sort);
    queryParameters.addAll(sortParams);

    return queryParameters;
  }

  Map<String, dynamic> _queryParametersForProductSort(ProductOrder sort) {
    Map<String, dynamic> queryParameters = {};

    const SORT_FIELD_KEY = 'sortField';
    const SORT_ASCENDING_KEY = 'sortAscending';

    if (sort != null && sort.parameterName != null) {
      switch (sort) {
        case ProductOrder.none:
          break;
        case ProductOrder.lowestPrice:
          queryParameters[SORT_FIELD_KEY] = 'price';
          queryParameters[SORT_ASCENDING_KEY] = true;
          break;
        case ProductOrder.higherPrice:
          queryParameters[SORT_FIELD_KEY] = 'price';
          queryParameters[SORT_ASCENDING_KEY] = false;
          break;
        case ProductOrder.mostFavored:
          queryParameters[SORT_FIELD_KEY] = 'favoriteCount';
          queryParameters[SORT_ASCENDING_KEY] = false;
          break;
        case ProductOrder.bestSellers:
          queryParameters[SORT_FIELD_KEY] = 'salesCount';
          queryParameters[SORT_ASCENDING_KEY] = false;
          break;
        case ProductOrder.releaseDate:
          queryParameters[SORT_FIELD_KEY] = 'releaseDate';
          queryParameters[SORT_ASCENDING_KEY] = false;
          break;
        case ProductOrder.aToZ:
          queryParameters[SORT_FIELD_KEY] = 'name';
          queryParameters[SORT_ASCENDING_KEY] = true;
          break;
        case ProductOrder.zToA:
          queryParameters[SORT_FIELD_KEY] = 'name';
          queryParameters[SORT_ASCENDING_KEY] = false;
          break;
      }
    }

    return queryParameters;
  }

  /// endregion

}
